@@ -16,7 +16,7 @@
 #'  square-root n. Default is TRUE.
 #' @param nvar Maximal number of variables allowed in the model.
 #' @return An "LB" class object is returned. The list contains the call, 
-#'  the type, the path, the intercept term a0 and value for alpha, kappa,
+#'  the family, the path, the intercept term a0 and value for alpha, kappa,
 #'  iter, and meanvalue, scale factor of X, meanx and normx.
 #' @references Ohser, Ruan, Xiong, Yao and Yin, Sparse Recovery via Differential
 #'  Inclusions, \url{http://arxiv.org/abs/1406.7728}
@@ -26,7 +26,9 @@
 #' #Examples in the reference paper
 #' library(MASS)
 #' library(lars)
-#' n = 200;p = 100;k = 30;sigma = 1
+#' library(MASS)
+#' library(lars)
+#' n = 80;p = 100;k = 30;sigma = 1
 #' Sigma = 1/(3*p)*matrix(rep(1,p^2),p,p)
 #' diag(Sigma) = 1
 #' A = mvrnorm(n, rep(0, p), Sigma)
@@ -36,26 +38,19 @@
 #' u_ref[supp_ref] = u_ref[supp_ref]+sign(u_ref[supp_ref])
 #' b = as.vector(A%*%u_ref + sigma*rnorm(n))
 #' lasso = lars(A,b,normalize=FALSE,intercept=FALSE,max.steps=100)
-#' attach(lasso)
-#' pdf(file="myplot.pdf")
-#' par(mfrow=c(3,2)) 
-#' plot(n/lambda,beta[1:100,1],type="l",xlim=c(0,3),ylim=c(min(beta),max(beta)),
-#'      xlab="t",ylab=bquote(beta),main="Lasso")
-#' for (i in 2:100){
-#'   points(n/lambda,beta[1:100,i],type="l")
-#' }
+#' par(mfrow=c(3,2))
+#' matplot(n/lasso$lambda, lasso$beta[1:100,], xlab = bquote(n/lambda), 
+#'         ylab = "Coefficients", xlim=c(0,3),ylim=c(range(lasso$beta)),type='l', main="Lasso")
 #' object = iss(A,b,intercept=FALSE,normalize=FALSE)
 #' plot(object,xlim=c(0,3),main=bquote("ISS"))
 #' kappa_list = c(4,16,64,256)
-#' alpha_list = 1/2/kappa_list
+#' alpha_list = 1/10/kappa_list
 #' for (i in 1:4){
-#'   object <- lb(A,b,kappa_list[i],alpha_list[i],family="gaussian",group="ungrouped",
+#'   object <- lb(A,b,kappa_list[i],alpha_list[i],family="gaussian",group=FALSE,
 #'                trate=20,intercept=FALSE,normalize=FALSE)
 #'   plot(object,xlim=c(0,3),main=bquote(paste("LB ",kappa,"=",.(kappa_list[i]))))
 #' }
-#' dev.off()
-#' 
-#' 
+#'
 
 iss <- function(X, y,intercept = TRUE, normalize = TRUE,nvar = min(dim(X)))
 {
@@ -118,7 +113,7 @@ iss <- function(X, y,intercept = TRUE, normalize = TRUE,nvar = min(dim(X)))
 	a0 <- mu - meanx%*%hist_path
 	hist_rho <- t(hist_rho[seq(i+1), ,drop=FALSE])
 	hist_t <- hist_t[seq(i+1)]*n
-	object <- list(call = call, type = c("Lasso", "ungrouped"), kappa = Inf, alpha = 0, path = hist_path, t = hist_t,iter = Inf, normx = normx,meanx = meanx,a0 = a0)
+	object <- list(call = call, family="gaussian",group=FALSE, kappa = Inf, alpha = 0, path = hist_path, t = hist_t,iter = Inf, normx = normx,meanx = meanx,a0 = a0)
 	class(object) <- "lb"
 	return(object)
 }
\ No newline at end of file
